@@ -101,6 +101,7 @@
 \\tempoWholesPerMinute
 \\tempo
 \\teeny
+\\tagGroup
 \\tag
 \\table-of-contents
 \\tablatureFormat
@@ -407,6 +408,7 @@
 \\majorSevenSymbol
 \\major
 \\maininput
+\\magnifyStaff
 \\magnifyMusic
 \\magnify
 \\lyricsto
@@ -721,6 +723,7 @@
 \\auto-footnote
 \\augmentum
 \\auctum
+\\associatedVoiceType
 \\assertBeamSlope
 \\assertBeamQuant
 \\ascendens
@@ -770,11 +773,8 @@
 \\B
 \\AncientRemoveEmptyStaffContext
 \\A
-warnings
-staff
 spacing
 signature
-shift
 routine
 notes
 handler
@@ -854,6 +854,7 @@ Note_name_engraver
 Note_heads_engraver
 Note_head_line_engraver
 NoteNames
+NoteHead
 New_fingering_engraver
 Multi_measure_rest_engraver
 Midi_control_function_performer
